# Wawesome Drupal Theme

Wawesome is a Drupal theme that utilizes the web component library of the
[Web Awesome](https://webawesome.com/) project.



## Installation

If you don't use asset-packgist for npm assets yet, include in your `composer.json`:

```
  "repositories": {
    "drupal": {
      "type": "composer",
      "url": "https://packages.drupal.org/8"
    },
    "asset-packagist": {
      "type": "composer",
      "url": "https://asset-packagist.org"
    }
    ...
  },
```

Next, define the installers and paths for the npm / bower assets  in your `composer.json`:

```
"extra": {
    "installer-types": ["bower-asset", "npm-asset"],
    "installer-paths": {
        "web/libraries/{$name}": ["type:drupal-library", "type:bower-asset", "type:npm-asset"]
    },
    ...
```

Run `composer up`

Then require the library:
`composer require 'npm-asset/awesome.me--webawesome'`

We also need Twig Tweak:
`composer require 'drupal/twig_tweak'`
Enable Twig Tweak in the module list or by calling
`drush en twig_tweak`


Finally, enable the theme in `/admin/appearance`




## SDC adapters for wa components (extending wawesom or creating a child theme)
We use the SDC mechanism in Drupal core to load web awesome components and pass
date to them.

In order to connect a web awesome (or any other) web component:
- define a library with the component's name in the `{theme-name}.libraries.yml`
that references the file to load, e.g.:

```
wa-animated-image:
  header: true
  js:
    /libraries/awesome.me--webawesome/dist/components/animated-image/animated-image.js: { minified: true, attributes: { type: "module" } }
```


- create a directory `wa-{component-name}`
- create a component definition: `wa-{component-name}.component.yml` (may be
empty but must exist for the scd mechanism to find it
- create a twig template `wa-{component-name}.twig` that attaches the formerly
defined library, and outputs the component and the passed parameters like:
```
{# see https://webawesome.com/docs/components/animated-image/ #}

{# Load the component via the library. #}
{{ attach_library('wawesome/wa-animated-image') }}

{# Preprocess variables #}
{% set src = src|default(null) %}
{% set alt = alt|default(null) %}

{# Render the compoonent #}
<wa-animated-image
  {% if src %}src="{{ src }}"{% endif %}
  {% if alt %}alt="{{ alt }}"{% endif %}
></wa-animated-image>
```
- Now, in a given field or paragraph template (or whatsoever), you can insert
the SDC component like:
```
{{ include('wawesome:wa-animated-image',
    {
      src: 'https://shoelace.style/assets/images/walk.gif',
      alt: 'Animation of untied shoes walking on pavement',
    }
  )
}}
```
- alternatively, you can also just attach the component's library and use the
component with its specific tag, omitting the SDC mechanism:
```
{{ attach_library('wawesome/wa-animated-image') }}
<wa-animated-image
  src="https://shoelace.style/assets/images/walk.gif"
  alt="Animation of untied shoes walking on pavement"
></wa-animated-image>
```
